/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Input Tag Properties Dialog.
 *
 * The Initial Developer of the Original Code is
 * Neil Rashbrook.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Neil Rashbrook <neil@parkwaycc.co.uk>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gInsertNewInput;
var inputElement;

// dialog initialization code

function Startup()
{
  if (!InitEditorShell())
    return;

  gDialog = {
    inputName:        document.getElementById( "InputName" ),
    inputDisabled:    document.getElementById( "InputDisabled" ),
    inputTabIndex:    document.getElementById( "InputTabIndex" )
  };

  ImageStartup();

  // Get a single selected input element
  var tagName = "input";
  inputElement = editorShell.GetSelectedElement(tagName);

  if (inputElement)
  {
    // We found an element and don't need to insert one
    gInsertNewInput = false;
  }
  else
  {
    gInsertNewInput = true;

    // We don't have an element selected,
    //  so create one with default attributes

    inputElement = editorShell.CreateElementWithDefaults(tagName);
    if( !inputElement )
    {
      dump("Failed to get selected element or create a new one!\n");
      window.close();
      return;
    }

    var imageElement = editorShell.GetSelectedElement("img");
    if (imageElement)
    {
      // We found an image element, convert it to an input type="image"
      var attributes = ["src", "alt", "width", "height", "hspace", "vspace", "border", "align"];
      for (i in attributes)
        inputElement.setAttribute(attributes[i], imageElement.getAttribute(attributes[i]));
    }
  }
  gInsertNewImage = !inputElement.hasAttribute("src");

  // Make a copy to use for AdvancedEdit
  globalElement = inputElement.cloneNode(false);

  InitDialog();

  InitMoreFewer();

  SetTextboxFocus(gDialog.inputName);

  SetWindowLocation();
}

function InitDialog()
{
  InitImage();
  gDialog.inputName.value = globalElement.getAttribute("name");
  gDialog.inputDisabled.setAttribute("checked", globalElement.hasAttribute("disabled"));
  gDialog.inputTabIndex.value = globalElement.getAttribute("tabindex");
}

function doOverallEnabling()
{
}

function ValidateData()
{
  if (!ValidateImage())
    return false;
  if (gDialog.inputName.value)
    globalElement.setAttribute("name", gDialog.inputName.value);
  else
    globalElement.removeAttribute("name");
  if (gDialog.inputTabIndex.value)
    globalElement.setAttribute("tabindex", gDialog.inputTabIndex.value);
  else
    globalElement.removeAttribute("tabindex");
  if (gDialog.inputDisabled.checked)
    globalElement.setAttribute("disabled", "");
  else
    globalElement.removeAttribute("disabled");
  return true;
}

function onAccept()
{
  if (ValidateData()) {
    // All values are valid - copy to actual element in doc or
    //   element created to insert

    globalElement.setAttribute("type", "image");

    editorShell.CloneAttributes(inputElement, globalElement);

    if (gInsertNewInput)
    {
      try {
        // 'true' means delete the selection before inserting
        // in case were are converting an image to an input type="image"
        editorShell.InsertElementAtSelection(inputElement, true);
      } catch (e) {
        dump(e);
      }
    }

    SaveWindowLocation();

    return true;
  }
  return false;
}

